# Generated by Django 5.2.9 on 2026-03-17 15:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('history4feed', '0009_feed_use_scrapfly_asp'),
    ]

    operations = [
        migrations.AlterField(
            model_name='post',
            name='description',
            field=models.CharField(blank=True, help_text='found in the <item> element of feed output', max_length=4194304),
        ),
    ]
